# insult_generator
Random insult generator, written in Python

[![Build Status](https://travis-ci.org/tr00st/insult_generator.svg?branch=master)](https://travis-ci.org/tr00st/insult_generator)
[![PyPI - License](https://img.shields.io/pypi/l/insultgenerator.svg)](https://pypi.org/project/insultgenerator/)
[![PyPI](https://img.shields.io/pypi/v/insultgenerator.svg)](https://pypi.org/project/insultgenerator/)

# Usage

	>>> from insultgenerator import phrases
	>>> phrases.get_so_insult_with_action_and_target("Your Mom", "she")
	"Your Mom's so ill-defined, she resituated the Tallula"
	>>> phrases.get_so_insult_with_action_and_target("Your Mom", "she")
	"Your Mom's so acerbic, she cold-chiselled the departmentalism"
	>>> phrases.get_so_insult_with_action_and_target("Your Mom", "she")
	"Your Mom's so bantam, she Indianized the tranquilizer"
	>>> phrases.get_so_insult_with_action_and_target("Your Mom", "she")
	"Your Mom's so fresh, she prussianised the Guesde"

# Disclaimer

No guarantees are made to the clarity or nonsensical nature of the insults created by this software.
